# Snek5000-cbox

<div align="center">

[![PyPI](https://img.shields.io/pypi/v/snek5000-cbox)](https://pypi.org/project/snek5000-cbox/)
[![Tests Status](https://github.com/snek5000/snek5000-cbox/workflows/Tests/badge.svg)](https://github.com/snek5000/snek5000-cbox/actions?workflow=Tests)

<!-- badges -->

</div>

A [Snek5000](https://github.com/snek5000/snek5000) solver for simulating
differentially heated and cooled convective box with
[NEK5000](https://nek5000.github.io/NekDoc/).

## Install

```bash
pip install snek5000-cbox
```

For more details, see https://snek5000.readthedocs.io/en/latest/install.html
